@@ -27,11 +27,11 @@ class PerldocProtocol : public KIO::SlaveBase
 {
 public:
     PerldocProtocol(const QByteArray &pool, const QByteArray &app);
-    virtual ~PerldocProtocol();
+    ~PerldocProtocol() override;
 
-    virtual void get(const KUrl& url);
-    virtual void stat(const KUrl& url);
-    virtual void listDir(const KUrl& url);
+    void get(const QUrl &url) override;
+    void stat(const QUrl &url) override;
+    void listDir(const QUrl &url) override;
 
     bool topicExists(const QString &topic);
 
@@ -40,6 +40,7 @@ protected:
     void failAndQuit();
 
     QString m_pod2htmlPath;
+    QString m_cssLocation;
 };
 
 #endif
